"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const i18next_1 = require("i18next");
const path = __importStar(require("path"));
const prompts_1 = require("@clack/prompts");
const picocolors_1 = __importDefault(require("picocolors"));
const integration_1 = require("../../domains/generate/integration");
const project_name_1 = require("../../domains/generate/project-name");
const git_repository_1 = require("../../domains/generate/git-repository");
const functions_1 = require("../../domains/generate/magento2/functions");
const terminalHelpers_1 = require("../../domains/generate/magento2/functions/terminalHelpers");
const installMagento_1 = require("../../domains/generate/magento2/installMagento");
const docker_1 = require("../../domains/generate/magento2/docker");
const installDeps_1 = __importDefault(require("../../domains/generate/magento2/functions/installDeps"));
const checkNode_1 = __importDefault(require("../../domains/generate/magento2/functions/checkNode"));
const checkYarn_1 = __importDefault(require("../../domains/generate/magento2/functions/checkYarn"));
const handleProjectDiretoryExists_1 = require("../../domains/generate/directory/handleProjectDiretoryExists");
const logger_1 = require("../../domains/generate/logging/logger");
class GenerateStore extends core_1.Command {
    async run() {
        let magentoDomain = "";
        const sp = (0, prompts_1.spinner)();
        const { writeLog, deleteLog } = (0, logger_1.initLogger)();
        (0, prompts_1.intro)((0, i18next_1.t)("command.generate_store.message.intro"));
        // get project name
        const projectName = await (0, project_name_1.getProjectName)((0, i18next_1.t)("command.generate_store.input.project_name"));
        const projectDir = path.resolve(projectName);
        // check if project directory exists and ask for overwrite
        await (0, handleProjectDiretoryExists_1.handleProjectDiretoryExists)({
            projectName,
            projectDir,
            sp,
        });
        // get integration
        const integration = await (0, integration_1.getIntegration)({
            message: (0, i18next_1.t)("command.generate_store.input.integration"),
            customIntegrationRepositoryMessage: (0, i18next_1.t)("command.generate_store.input.custom_integration_repository"),
        });
        const { name: integrationName } = integration;
        const isMagento2 = integrationName === "Magento 2";
        await (0, checkNode_1.default)(writeLog);
        await (0, checkYarn_1.default)(writeLog);
        // install Magento 2 if needed
        if (isMagento2) {
            const isInstallMagento = await (0, functions_1.installMg2Prompt)((0, i18next_1.t)("command.generate_store.magento.install"));
            if ((0, prompts_1.isCancel)(isInstallMagento)) {
                (0, terminalHelpers_1.logSimpleWarningMessage)((0, i18next_1.t)("command.generate_store.message.canceled"));
                process.exit(0);
            }
            if (isInstallMagento) {
                await (0, docker_1.checkDocker)(writeLog);
                const { magentoDirName, magentoAccessKey, magentoSecretKey } = await (0, functions_1.getMagentoDetails)(projectName);
                magentoDomain = await (0, docker_1.getMagentoDomainName)((0, i18next_1.t)("command.generate_store.magento.domain"));
                await (0, installMagento_1.installMagento)({
                    isInstallMagento,
                    magentoDirName,
                    magentoDomain,
                    magentoAccessKey,
                    magentoSecretKey,
                    writeLog,
                });
            }
            else {
                magentoDomain = await (0, docker_1.getMagentoDomainName)((0, i18next_1.t)("command.generate_store.magento.domain"));
            }
        }
        // generate VSF project
        sp.start((0, i18next_1.t)("command.generate_store.progress.vsf_start"));
        await (0, git_repository_1.cloneGitRepository)({
            projectDir,
            gitRepositoryURL: integration.gitRepositoryURL,
        });
        // copy .env file if Magento 2 integration
        if (isMagento2) {
            await (0, functions_1.copyEnv)(projectDir, magentoDomain);
        }
        await (0, git_repository_1.terminateGitRepository)(projectDir);
        sp.stop(picocolors_1.default.green((0, i18next_1.t)("command.generate_store.progress.vsf_end")));
        // install dependencies
        await (0, installDeps_1.default)(projectDir, writeLog);
        // show success message
        if (integration.documentationURL) {
            (0, prompts_1.note)((0, i18next_1.t)("command.generate_store.message.configure", {
                documentationURL: integration.documentationURL,
            }));
        }
        deleteLog();
        (0, terminalHelpers_1.simpleLog)((0, i18next_1.t)("command.generate_store.message.cd_message"));
        (0, terminalHelpers_1.simpleLog)((0, i18next_1.t)("command.generate_store.message.cd_directory", {
            projectName,
        }), picocolors_1.default.magenta);
        (0, terminalHelpers_1.simpleLog)((0, i18next_1.t)("command.generate_store.message.start"));
        (0, terminalHelpers_1.simpleLog)((0, i18next_1.t)("command.generate_store.message.start_command", {
            projectName,
        }), picocolors_1.default.magenta);
        (0, terminalHelpers_1.simpleLog)("");
        (0, terminalHelpers_1.simpleLog)("Happy coding! 🎉", picocolors_1.default.green);
        this.exit(0);
    }
}
exports.default = GenerateStore;
GenerateStore.description = (0, i18next_1.t)("command.generate_store.description");
GenerateStore.examples = ["<%= config.bin %> <%= command.id %>"];
GenerateStore.flags = {};
GenerateStore.args = [];
