"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const prompts_1 = require("@clack/prompts");
const core_1 = require("@oclif/core");
const picocolors_1 = __importDefault(require("picocolors"));
const i18next_1 = require("i18next");
const logger_1 = require("../domains/generate/logging/logger");
const docker_1 = require("../domains/generate/magento2/docker");
const functions_1 = require("../domains/generate/magento2/functions");
const installMagento_1 = require("../domains/generate/magento2/installMagento");
const terminalHelpers_1 = require("../domains/generate/magento2/functions/terminalHelpers");
class M2Only extends core_1.Command {
    async run() {
        const { writeLog, deleteLog } = (0, logger_1.initLogger)();
        (0, prompts_1.intro)("Welcome to the Magento 2 local instance installer!");
        await (0, docker_1.checkDocker)(writeLog);
        const { magentoDirName, magentoAccessKey, magentoSecretKey } = await (0, functions_1.getMagentoDetails)();
        const magentoDomain = await (0, docker_1.getMagentoDomainName)((0, i18next_1.t)("command.generate_store.magento.domain"));
        await (0, installMagento_1.installMagento)({
            isInstallMagento: true,
            magentoDirName,
            magentoDomain,
            magentoAccessKey,
            magentoSecretKey,
            writeLog,
        });
        deleteLog();
        (0, terminalHelpers_1.simpleLog)("Happy coding! 🎉", picocolors_1.default.green);
        this.exit(0);
    }
}
exports.default = M2Only;
M2Only.description = "Install local Magento 2 instance";
M2Only.examples = ["<%= config.bin %> <%= command.id %>"];
M2Only.flags = {};
M2Only.args = [];
