"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleDirectoryName = void 0;
const fs_1 = __importDefault(require("fs"));
const prompts_1 = require("@clack/prompts");
const picocolors_1 = __importDefault(require("picocolors"));
const utils_1 = require("../../../../utils");
const handleDirectoryName = async (projectDir) => {
    let directoryName = projectDir;
    const sp = (0, prompts_1.spinner)();
    if (!directoryName) {
        directoryName = (await (0, prompts_1.text)({
            message: "How we will name your integration?",
        }));
        if ((0, prompts_1.isCancel)(directoryName)) {
            (0, utils_1.log)("Integration creation has been canceled");
            process.exit(0);
        }
    }
    const isDirExists = await (0, utils_1.existsDirectory)(directoryName);
    if (isDirExists) {
        const isOverwrite = await (0, prompts_1.confirm)({
            message: `Directory ${directoryName} already exists. Do you want to overwrite it?`,
            active: "Yes",
        });
        if ((0, prompts_1.isCancel)(isOverwrite)) {
            (0, utils_1.log)("Integration creation has been canceled");
            process.exit(0);
        }
        if (isOverwrite) {
            sp.start(picocolors_1.default.cyan("deleting directory..."));
            await fs_1.default.rmSync(directoryName, { recursive: true, force: true });
            await fs_1.default.mkdirSync(directoryName);
            sp.stop(picocolors_1.default.green("directory has been deleted!"));
        }
        else {
            await (0, exports.handleDirectoryName)("");
        }
    }
    return directoryName;
};
exports.handleDirectoryName = handleDirectoryName;
