"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeUnwantedFiles = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const ESLINT_FILES = [".eslintrc.js", ".eslintignore", ".eslintrc.json"];
const COMMITLINT_FILES = ["commitlint.config.js"];
const OTHER_FILES = ["CHANGELOG.md", "/playground/app/exampleApp.md"];
const removeFromPackageJson = async (directoryName, packageName) => {
    const packageJSONPath = path_1.default.join(directoryName, "package.json");
    const packageJson = JSON.parse(fs_1.default.readFileSync(packageJSONPath, "utf8"));
    const dependencies = packageJson.dependencies || {};
    const devDependencies = packageJson.devDependencies || {};
    if (packageJson["lint-staged"]) {
        delete packageJson["lint-staged"];
    }
    // Loop through the dependencies section
    Object.keys(dependencies).forEach((dependency) => {
        if (dependency.includes(packageName)) {
            delete dependencies[dependency];
        }
    });
    // Loop through the devDependencies section
    Object.keys(devDependencies).forEach((dependency) => {
        if (dependency.includes(packageName)) {
            delete devDependencies[dependency];
        }
    });
    packageJson.dependencies = dependencies;
    packageJson.devDependencies = devDependencies;
    fs_1.default.writeFileSync(packageJSONPath, JSON.stringify(packageJson, null, 2));
};
const removeFiles = async (directoryName, files) => {
    files.forEach((file) => {
        const filePath = path_1.default.join(directoryName, file);
        if (fs_1.default.existsSync(filePath)) {
            fs_1.default.unlinkSync(filePath);
        }
    });
    fs_1.default.readdirSync(directoryName).forEach((file) => {
        const filePath = path_1.default.join(directoryName, file);
        if (fs_1.default.statSync(filePath).isDirectory()) {
            removeFiles(filePath, files);
        }
    });
};
const removeUnwantedFiles = async (directoryName) => {
    const rootDir = directoryName;
    const playgroundDir = `${directoryName}/playground/app`;
    await removeFromPackageJson(rootDir, "eslint");
    await removeFromPackageJson(playgroundDir, "eslint");
    await removeFromPackageJson(rootDir, "commitlint");
    await removeFiles(rootDir, ESLINT_FILES);
    await removeFiles(playgroundDir, ESLINT_FILES);
    await removeFiles(rootDir, COMMITLINT_FILES);
    await removeFiles(rootDir, OTHER_FILES);
};
exports.removeUnwantedFiles = removeUnwantedFiles;
