"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const i18next_1 = require("i18next");
const prompts_1 = require("@clack/prompts");
const confirmOverwrite_1 = __importDefault(require("../prompts/confirmOverwrite"));
const getMagentoDirName_1 = __importDefault(require("../prompts/getMagentoDirName"));
const isMagentoKeys_1 = __importDefault(require("../prompts/isMagentoKeys"));
const terminalHelpers_1 = require("./terminalHelpers");
const handleMagentoKeys_1 = __importDefault(require("../prompts/handleMagentoKeys"));
const getMagentoDetails = async (projectName) => {
    let magentoAccessKey;
    let magentoSecretKey;
    (0, prompts_1.note)((0, i18next_1.t)("command.generate_store.magento.info"));
    let magentoDirName = await (0, getMagentoDirName_1.default)((0, i18next_1.t)("command.generate_store.magento.directory"));
    if (magentoDirName === projectName) {
        (0, terminalHelpers_1.logSimpleErrorMessage)((0, i18next_1.t)("command.generate_store.magento.error.same_dir", {
            magentoDirName,
            projectName,
        }));
        magentoDirName = await (0, getMagentoDirName_1.default)((0, i18next_1.t)("command.generate_store.magento.directory"));
    }
    if (!fs_1.default.existsSync(magentoDirName)) {
        fs_1.default.mkdirSync(magentoDirName);
    }
    else {
        magentoDirName = await (0, confirmOverwrite_1.default)({
            message: (0, i18next_1.t)("command.generate_store.magento.overwrite", {
                magentoDirName,
            }),
            magentoDirName,
        });
    }
    const hasMagentoKeys = await (0, isMagentoKeys_1.default)((0, i18next_1.t)("command.generate_store.magento.access_keys"));
    if (hasMagentoKeys) {
        (0, terminalHelpers_1.simpleLog)((0, i18next_1.t)("command.generate_store.magento.provide_keys"));
        const { accessKey, secretKey } = await (0, handleMagentoKeys_1.default)();
        magentoAccessKey = accessKey;
        magentoSecretKey = secretKey;
    }
    else {
        (0, terminalHelpers_1.simpleLog)((0, i18next_1.t)("command.generate_store.magento.no_keys"));
        (0, terminalHelpers_1.simpleLog)((0, i18next_1.t)("command.generate_store.magento.provide_keys"));
        const { accessKey, secretKey } = await (0, handleMagentoKeys_1.default)();
        magentoAccessKey = accessKey;
        magentoSecretKey = secretKey;
    }
    return {
        magentoDirName,
        magentoAccessKey,
        magentoSecretKey,
    };
};
exports.default = getMagentoDetails;
